%% File: ktsnote.cls Copyright 2010 Jin-Hwan Cho.
%%
%% This file is part of the `Korean TeX Society Bundle'.
%% -----------------------------------------------------
%%
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%%
%% This work has the LPPL maintenance status `maintained'.
%%
%% The Current Maintainer of this work is Jin-Hwan Cho.
%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ktsnote}[2010/11/01 v0.1]
%
% initial code
%
\RequirePackage{ifxetex}
\RequireXeTeX
%
\RequirePackage{ifthen}
\newboolean{@palatino}
\newboolean{@optima}
\newboolean{@yoon}
\newboolean{@nanummj}
\newboolean{@nanumgt}
%
%\RequirePackage{calc}
%
% declaration of options
%
\DeclareOption{palatino}{\setboolean{@palatino}{true}}
\DeclareOption{optima}{\setboolean{@optima}{true}}
\DeclareOption{yoon}{\setboolean{@yoon}{true}}
\DeclareOption{nanum}{\setboolean{@nanummj}{true}\setboolean{@nanumgt}{true}}
\DeclareOption{nanummj}{\setboolean{@nanummj}{true}}
\DeclareOption{nanumgt}{\setboolean{@nanumgt}{true}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{memoir}}
%
% execution of options
%
\ExecuteOptions{a4paper,10pt,oneside}
\ProcessOptions
%
% package loading
%
\LoadClass{memoir}
\RequirePackage{amsmath,amssymb,amsthm}
\RequirePackage{mathrsfs}
\RequirePackage{mathspec}
\RequirePackage{xltxtra}
%
% latin fonts
%
\setmainfont[
  Mapping=tex-text, ExternalLocation, UprightFont={*-regular},
  BoldFont={*-bold}, ItalicFont={*-italic}, BoldItalicFont={*-bolditalic}
]{texgyrepagella}
\setsansfont[
  Mapping=tex-text, ExternalLocation, UprightFont={*-regular},
  BoldFont={*-bold}, ItalicFont={*-italic}, BoldItalicFont={*-bolditalic}
]{texgyreheros}
\ifthenelse{\boolean{@palatino}}{% Palatino
  \setmainfont[Mapping=tex-text]{Palatino Linotype}
}{}
\ifthenelse{\boolean{@optima}}{% Optima
  \setsansfont[Mapping=tex-text]{Optima}
}{}
%
% hangul fonts
%
\RequirePackage{xetexko}
\xetexkofontregime[%
  quotes=hangul, parens=hangul, puncts=prevfont,
  hyphens=prevfont, colons=prevfont, cjksymbols=hanja
]{latin}
% 함초롬 바탕, 함초롬 돋움
\setmainhangulfont[
  Mapping=tex-text, Renderer=ICU, preperiodkern=-.05em, precommakern=-.05em
]{HCR Batang}
\setsanshangulfont[
  Mapping=tex-text, Renderer=ICU
]{HCR Dotum}
\setmainhanjafont[
  Mapping=tex-text, Renderer=ICU, preperiodkern=-.05em, precommakern=-.05em
]{HCR Batang}
\setsanshanjafont[
  Mapping=tex-text, Renderer=ICU
]{HCR Dotum}
% 나눔고딕코딩
\setmonohangulfont[Renderer=ICU]{NanumGothicCoding}
\setmonohanjafont [Renderer=ICU]{NanumGothic}
\ifthenelse{\boolean{@yoon}}{% 윤명조, 윤고딕
  \setmainhangulfont[
    Mapping=tex-text, Renderer=ICU, UprightFont={* Light}, BoldFont={* Medium},
    interhchar=-.2pt, preperiodkern=-1pt
  ]{YoonMyungjo}
  \setsanshangulfont[
    Mapping=tex-text, Renderer=ICU, UprightFont={* Light}, BoldFont={* Medium},
    interhchar=-.2pt, preperiodkern=-1pt
  ]{YoonGothic}
  \setmainhanjafont[
    Mapping=tex-text, Renderer=ICU, UprightFont={* Light}, BoldFont={* Medium},
    interhchar=-.2pt, preperiodkern=-1pt
  ]{YoonMyungjo}
  \setsanshanjafont[
    Mapping=tex-text, Renderer=ICU, UprightFont={* Light}, BoldFont={* Medium},
    interhchar=-.2pt, preperiodkern=-1pt
  ]{YoonGothic}
}{}
\ifthenelse{\boolean{@nanummj}}{% 나눔명조
  \setmainhangulfont[
    Mapping=tex-text, Renderer=ICU, %BoldFont={* ExtraBold}
  ]{NanumMyeongjo}
}{}
\ifthenelse{\boolean{@nanumgt}}{% 나눔고딕
  \setsanshangulfont[
    Mapping=tex-text, Renderer=ICU, %BoldFont={* ExtraBold}
  ]{NanumGothic}
  \setsanshanjafont[
    Mapping=tex-text, Renderer=ICU, %BoldFont={* ExtraBold}
  ]{NanumGothic}
}{}
%
% hangul commands
%
\newcommand\cnm[1]{〈#1〉}
\newcommand\ccnm[1]{《#1》}
\newcommand\snm[1]{「#1」}
\newcommand\bnm[1]{『#1』}
\newcommand\hcntdot{\nobreak\mbox{$\cdot$}}
\newcommand\cntrdot{\kern.2em\hcntdot\nobreak\hskip.2em}
\newcommand\cntrdots{\kern.2em\hcntdot\nobreak\hskip.2em\hcntdot\nobreak\hskip.2em\hcntdot\nobreak\hskip.4em}
%
% other packages
%
%\RequirePackage{array}
%\RequirePackage{paralist} % for compactitem and compactenum
%
% page layout
%
\setlrmarginsandblock{*}{1in}{1.1}
\setulmarginsandblock{*}{1in}{1.1}
\checkandfixthelayout
%
% page style
%
\makepagestyle{lecture}
\makeevenhead{lecture}{\@lecturesubj}{\@lecturename}{\@lectureseme}
\makeevenfoot{lecture}{\@lecturedate}{}{\@lecturepage}
\makeoddhead {lecture}{\@lecturesubj}{\@lecturename}{\@lectureseme}
\makeoddfoot {lecture}{\@lecturedate}{}{\@lecturepage}
\makeheadrule{lecture}{\textwidth}{\normalrulethickness}
%\pagestyle{showlocs}
\newcommand\setthesubj[1]{\def\@lecturesubj{#1}}
\newcommand\setthename[1]{\def\@lecturename{#1}}
\newcommand\settheseme[1]{\def\@lectureseme{#1}}
\newcommand\setthedate[1]{\def\@lecturedate{#1}}
\newcommand\setthepage[1]{\def\@lecturepage{#1}}
\setthesubj{}
\setthename{\sffamily\large LECTURE NOTES}
\settheseme{}
\setthedate{\today}
\setthepage{Page \thepage\,/\,\thelastpage}
\pagestyle{lecture}
%% remove left margin for itemize, enumerate, etc.
%\setlength{\leftmargini}{3.25em}
%%\setlength{\leftmarginii}{1.5em}
\setlength{\parskip}{.25\baselineskip}
\setlength{\fboxsep}{1pt}

\raggedbottom
%
% new commands
%
\newcounter{lecture} \setcounter{lecture}{0}
\newcommand{\lecturename}{Lecture}
\newcommand{\setthelect}[1]{\def\@lecturehead{#1}}
\setthelect{\MakeUppercase{\lecturename}~\thelecture.\enspace}
\newcommand{\lecture}[1]{%
  \addtocounter{lecture}{1}
  \setcounter{subsection}{0}
  \section*{\protect\@lecturehead #1}
}
\setsecnumdepth{subsection}
\counterwithin{subsection}{lecture}
\setsubsecheadstyle{\normalfont\bfseries\memRTLraggedright}%
\newcommand{\leftunderline}[1]{\parbox{4em}{\hfill\raisebox{2pt}{#1}\hrule height 1pt}}
\setsubsechook{\setsecnumformat{\llap{\leftunderline{\csname the##1\endcsname}\quad}}}
\setaftersubsecskip{-\parindent}
%
\DeclareRobustCommand{\em}{%
  \@nomath\em
  \ifdim\fontdimen\@ne\font > \z@
    \eminnershape
  \else
    \emoutershape
  \fi}
\let\emoutershape\itshape
% Conflict with xunicode.sty for palatino fonts
\DeclareRobustCommand{\textellipsis}{%
   .\kern\fontdimen3\font
   .\kern\fontdimen3\font
   .\kern\fontdimen3\font}

\newcommand{\REF}[2]{%
  {\setlength{\fboxsep}{1pt}\fbox{\ref{#1}}\thinspace#2}}
\newcommand{\BOOK}[1]{%
  \thinspace{\setlength{\fboxsep}{1pt}\fbox{\sffamily\footnotesize #1}}}
\newcommand{\Ref}[1]{\REF{#1}{#1}}

\endinput

\setcounter{tocdepth}{1}
\renewcommand*{\l@section}{\@dottedtocline{1}{1.5em}{5em}}
\renewcommand{\labelenumi}{(\theenumi)}
\renewcommand{\theenumi}{\alph{enumi}}
\renewcommand{\theenumii}{\roman{enumii}}

% definitions
\newlength\templength
\newbox\tempbox
\newenvironment{solution}{\begin{proof}[Solution]}{\end{proof}}
%\newenvironment{solution}{\savebox{\tempbox}\bgroup\vbox\bgroup}{\egroup\egroup}
\newenvironment{exercise}[1][Exercises]{\par
  \subsection{#1}
  \setlength{\leftmargini}{1.5em}
  \setlength{\leftmarginii}{1.5em}
  \renewcommand{\labelenumi}{\theenumi.}
  \renewcommand{\theenumi}{\arabic{enumi}}
  \renewcommand{\theenumii}{\alph{enumii}}
  \begin{enumerate}
}{%
  \end{enumerate}
}
\newenvironment{Enumerate}%
  {\bgroup\setlength{\parskip}{0pt}\begin{enumerate}}%
  {\end{enumerate}\egroup}

\newcommand*{\classinfo}[7]{%
  \gdef\subjname{#1}
  \gdef\codename{#2}
  \gdef\docuname{#3}
  \gdef\univname{#4}
  \gdef\yearname{#5}
  \gdef\semename{#6}
  \gdef\authname{#7}
  }
\newcommand{\ulsc}[1]{%
  \underline{\textsc{#1}}}
\newcommand{\divline}{%
  \vspace{2ex}
  \begin{center}
  \rule[2pt]{1in}{.5pt} $\circ$
  \rule[2pt]{1in}{.5pt} $\circ$
  \rule[2pt]{1in}{.5pt}
  \end{center}}
\newcommand{\WORD}{\@ifnextchar[\twoterm\oneterm}
\def\twoterm[#1]#2{\oneterm{#2}\textsf{\small[#1]}}
\def\oneterm#1{\emph{#1}}

\ifthenelse{\boolean{@syllabus}}{%
  \renewcommand{\descriptionlabel}[1]{%
    {\hspace{\labelsep}\sffamily\bfseries #1}}
  \newcommand*{\classtitle}{%
    \settowidth{\templength}{\subjname}%
    \begin{center} \sffamily\bfseries
      {\LARGE\hbadness=10000\makebox[2\templength][s]{\subjname}\hspace{.5em}(\codename)}
      \par\vspace{2ex}
      {\large \univname\space\yearname년 \semename학기 \docuname}
      \par\vspace{4ex}
    \end{center}}
}{}

\ifthenelse{\boolean{@solution}}{%
  \setlength{\leftmargini}{1.5em}
  \setlength{\leftmarginii}{1.5em}
  \renewcommand{\labelenumi}{\theenumi.}
  \renewcommand{\theenumi}{\arabic{enumi}}
  \renewcommand{\theenumii}{\alph{enumii}}
  \let\emph\textit

  \newcommand{\True}{\space$\bigcirc$\space}
  \newcommand{\False}{\space{\Large$\times$}\space}

  \setcounter{week}{0}
}{}

\renewcommand{\cleardoublepage}{\clearpage\ifodd\c@page\else\hbox{}\newpage\fi}

\endinput
